# eric7.Preferences.ConfigurationPages.PdfViewerPage

Module implementing the PDF Viewer configuration page.

### Global Attributes

None

### Classes

PdfViewerPage | Class implementing the PDF Viewer configuration page.

### Functions

create | Module function to create the configuration page.

## PdfViewerPage

Class implementing the PDF Viewer configuration page.

### Derived from

ConfigurationPageBase, Ui_PdfViewerPage

### Class Attributes

None

### Class Methods

None

### Methods

PdfViewerPage | Constructor
save | Public slot to save the IRC configuration.

### Static Methods

None

#### PdfViewerPage (Constructor)

PdfViewerPage()

Constructor

#### PdfViewerPage.save

save()

Public slot to save the IRC configuration.

Up

## create

create(_dlg)

Module function to create the configuration page.

_dlg (ConfigurationDialog)
  reference to the configuration dialog (unused)

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up